@@ -11,7 +11,7 @@ if __name__ == "__main__":
 
     Client.send_data(b'Test') #sends the text to the Server
     while True:
-        if Client.new_data_recved: #checks if any data recved
+        if Client.event.new_data: #checks if any data recved
             data = Client.return_recved_data() #returns the recved data as a list
             for element in data:
                 print(element) #should return b'Test'
\ No newline at end of file
