@@ -43,6 +43,13 @@ class TCPClient:
         self.on_disconnect = None
         self.on_receive = None
 
+    def __str__(self):
+        return f'[socket : {str(self.socket)}, target address : ({self.__target_ip},{self.__target_port}), ' \
+               f'receive buffer: {self.__recv_buffer}]'
+
+    def __repr__(self):
+        return f'[{str(self.socket)},({self.__target_ip},{self.__target_port}),{self.__recv_buffer}]'
+
     def setup(self, target_ip: str, target_port: int = 25567, recv_buffer: int = 2048, on_connect=None,
               on_disconect=None, on_receive=None):
         self.__target_ip = target_ip
@@ -199,6 +206,13 @@ class TCPServer:
         self.__PORT = None
         self.__IP = None
 
+    def __str__(self):
+        return f'[socket : {str(self.socket)}, address : ({self.__IP},{self.__PORT}), ' \
+               f'receive buffer: {self.__recv_buffer}]'
+
+    def __repr__(self):
+        return f'[{str(self.socket)},({self.__IP},{self.__PORT}),{self.__recv_buffer}]'
+
     # Prepares the Server
     def setup(self, ip: str = socket.gethostname(), port: int = 25567, listen: int = 5, recv_buffer: int = 2048,
               handle_client=None, on_connect=None, on_disconnect=None, on_receive=None):
@@ -265,7 +279,7 @@ class TCPServer:
                     self.recved_data.append((client_socket, address, recved))
 
                     if callable(self.on_receive):
-                        self.on_receive(recved)
+                        self.on_receive(client_socket, address, recved)
 
         except Exception as e:
             self.event.exception.list.append((traceback.format_exc(), e))
